#########################################
#### Two-step fsQCA REACTIVE CONFLICTS
####
#### OUT1: Non-legal means of protest (sabotage, occupation, violence)
####
#### Date of analysis: June 14, 2021
####
#########################################


rm(list = ls())

library(QCA)
library(SetMethods)

setwd

DAT <- read.csv("Normalized scores_reactive.csv", row.names=1, sep= ";")
DAT

head(DAT)

## checking for skewedness

xy.plot("Participation", "OUT1", DAT, jitter=TRUE)
## only 2 cases have it! --> Strongly skewed, exclude

xy.plot("Livelihoods", "OUT1", DAT, jitter=TRUE)
## 7 cases out of 30 do not have it --> somewhat skewed

xy.plot("Dependency", "OUT1", DAT, jitter=TRUE)
## 11 cases do not have it 

xy.plot("INGOs", "OUT1", DAT, jitter=TRUE)
## 6 cases have it --> somewhat skewed

xy.plot("Marginalization", "OUT1", DAT, jitter=TRUE)
## 8 cases do not have it 

xy.plot("Scarcity", "OUT1", DAT, jitter=TRUE)
## no skewedness

xy.plot("Narratives", "OUT1", DAT, jitter=TRUE)
## no skewedness

xy.plot("Tensions", "OUT1", DAT, jitter=TRUE)
## only 6 do not have it, 2 undefined --> some skewedness

xy.plot("Internal.conflicts", "OUT1", DAT, jitter=TRUE)
## 11 have it -

xy.plot("OUT2", "OUT1", DAT, jitter=TRUE)
## no skewedness

xy.plot("Impact", "OUT1", DAT, jitter=TRUE)
## only 1 does not have it --> strongly skewed, exclude

xy.plot("Cultural", "OUT1", DAT, jitter=TRUE)
## 11 do not have it 

xy.plot("State", "OUT1", DAT, jitter=TRUE)
## 7 do not have it --> somewhat skewed

#########
##
## result of skewedness check:
##
## Strongly skewed: Participation, Impact --> exlude from analysis
## Somewhat skewed: Livelihoods (7/30), INGOs (6/30), State (7/30), Tensions (6/2/30), Marginalization (8/30)
##
#########

## same strategy as for preventive conflicts
## exclude conditions with variance at/below 20%: participation, impact, ingos

#####################################
##
## Analysis Y
##
#################################
##
## Necessity remote conditions
##
##################################

conds <- c("State", "Scarcity", "Tensions", "Marginalization", "Livelihoods")
conds

SUIN_y <- superSubset(data = DAT,
                      outcome = "OUT1",
                      condition = c("State", "Scarcity", "Tensions", "Marginalization", "Livelihoods"),
                      incl.cut = 0.9,
                      cov.cut=0.6,
                      ron.cut = 0.5,
                      depth = 2,
                      show.cases= TRUE)

SUIN_y

## Marginalization*Livelihoods

##                                  inclN   RoN   covN  
## --------------------------------------------------- 
##  1  Marginalization*Livelihoods  0.921  0.667  0.657 

#############################
##
## Sufficiency Y
##
#############################

head(DAT)

TT_y <- truthTable(data=DAT,
                    outcome= "OUT1",
                    condition = c("Marginalization", "Livelihoods", "Cultural", "Narratives", "Dependency", "Coercion", "Internal.conflicts"),
                    incl.cut=0.9,
                    show.cases=TRUE,
                    complete=TRUE,
                    sort.by= c("OUT", "incl"))
TT_y


## TT row 120 has incl.cut 0.87, PRI 0.625, include

TT_y <- truthTable(data=DAT,
                   outcome= "OUT1",
                   condition = c("Marginalization", "Livelihoods", "Cultural", "Narratives", "Dependency", "Coercion", "Internal.conflicts"),
                   incl.cut=0.86,
                   show.cases=TRUE,
                   complete=TRUE,
                   sort.by= c("OUT", "incl"))
TT_y

sol_y <- minimize(TT_y,
                   show.cases = TRUE,
                   details=TRUE)
sol_y

## M1: Marginalization*Livelihoods*Cultural*Dependency*Coercion*Internal.conflicts +
##     Marginalization*Livelihoods*Narratives*Dependency*Coercion*Internal.conflicts +
##     Marginalization*Livelihoods*~Cultural*~Narratives*Dependency*Coercion*~Internal.conflicts
##      -> OUT1

sol_yp <- minimize(TT_y,
                    show.cases = TRUE,
                    include= "?",
                    details=TRUE)
sol_yp

## M1: Marginalization*Dependency*Coercion -> OUT1

pimplot(data = DAT, 
        results = sol_yp, 
        outcome = "OUT1",
        jitter=TRUE,
        all_labels= TRUE)

## no contradictions in kind
## STE, TEM, PAT, MCM have the outcome but are not explained
## LI1, BYA, GAR, DEL, SOS, BAN have the outcome and are explained

#######################################################################
#######################################################################
##
## Necessity ~Y
##
#################

SUIN_ny <- superSubset(data = DAT,
                      outcome = "~OUT1",
                      condition = c("State", "Scarcity", "Tensions", "Marginalization", "Livelihoods"),
                      incl.cut = 0.9,
                      cov.cut=0.6,
                      ron.cut = 0.5,
                      depth = 2,
                      show.cases= TRUE)

## none with ron.cut 0.5

######################
##
## Sufficiency ~Y
##
#####################

TT_ny <- truthTable(data=DAT,
                   outcome= "~OUT1",
                   condition = c("Cultural", "Narratives", "Dependency", "Coercion", "Internal.conflicts"),
                   incl.cut=0.9,
                   show.cases=TRUE,
                   complete=TRUE,
                   sort.by= c("OUT", "incl"))
TT_ny

## tt rows 29 and 1 have 3 and 1 case each, PRIs of 0.667 and incl.cut of 0.863, 0.861 respectively. Include

TT_ny <- truthTable(data=DAT,
                    outcome= "~OUT1",
                    condition = c("Cultural", "Narratives", "Dependency", "Coercion", "Internal.conflicts"),
                    incl.cut=0.861,
                    show.cases=TRUE,
                    complete=TRUE,
                    sort.by= c("OUT", "incl"))
TT_ny


sol_ny <- minimize(TT_ny,
                  show.cases = TRUE,
                  details=TRUE,
                  use.tilde=FALSE)
sol_ny

## Model ambiguity with four solutions:

## M1: Cultural*~Narratives*~Coercion + Cultural*Dependency*~Coercion +
##     ~Narratives*~Coercion*~Internal.conflicts +
##     (Dependency*~Coercion*~Internal.conflicts +
##     ~Cultural*Narratives*Coercion*~Internal.conflicts +
##     Cultural*~Dependency*Coercion*~Internal.conflicts) -> ~OUT1 

## M2: Cultural*~Narratives*~Coercion + Cultural*Dependency*~Coercion +
##     ~Narratives*~Coercion*~Internal.conflicts +
##     (~Cultural*Narratives*Dependency*~Internal.conflicts +
##     ~Cultural*Narratives*Coercion*~Internal.conflicts +
##     Cultural*~Dependency*Coercion*~Internal.conflicts) -> ~OUT1 

## M3: Cultural*~Narratives*~Coercion + Cultural*Dependency*~Coercion +
##     ~Narratives*~Coercion*~Internal.conflicts +
##     (~Cultural*Narratives*Dependency*~Internal.conflicts +
##     Cultural*~Narratives*~Dependency*~Internal.conflicts +
##     Narratives*~Dependency*Coercion*~Internal.conflicts) -> ~OUT1 

## M4: Cultural*~Narratives*~Coercion + Cultural*Dependency*~Coercion +
##     ~Narratives*~Coercion*~Internal.conflicts +
##     (~Cultural*Narratives*Dependency*~Internal.conflicts +
##     Cultural*~Dependency*Coercion*~Internal.conflicts +
##     Narratives*~Dependency*Coercion*~Internal.conflicts) -> ~OUT1 

sol_nyp <- minimize(TT_ny,
                   show.cases = TRUE,
                   include= "?",
                   details=TRUE)
sol_nyp

## still model ambiguity


pimplot(data = DAT, 
        results = sol_nyp, 
        outcome = "~OUT1",
        jitter=TRUE,
        all_labels= TRUE)

## two contradictions in kind: MCM, STE (MCM contradicts DEPENDENCY*coercion, STE contradicts narratives*coercion)
## unexplained: DUR-1, SAI, PER

#########################################################
#########################################################
##
## ESA
##
########################################################
##
## Sufficiency Y
##
##################

##############################################################
##
## Step 1: Contradicts statement of necessity
##
########################


TT_esa <- esa(TT_y, 
              nec_cond = c("Marginalization*Livelihoods"))
TT_esa

sol_esa <- minimize(TT_esa,
                    show.cases = TRUE,
                    details=TRUE)
sol_esa

## M1: Marginalization*Livelihoods*Cultural*Dependency*Coercion*Internal.conflicts +
##     Marginalization*Livelihoods*Narratives*Dependency*Coercion*Internal.conflicts +
##     Marginalization*Livelihoods*~Cultural*~Narratives*Dependency*Coercion*~Internal.conflicts
##     -> OUT1

sol_esap <- minimize(TT_esa,
                     show.cases = TRUE,
                     include= "?",
                     details=TRUE)
sol_esap

##                                                     inclS   PRI   covS   covU  
## -------------------------------------------------------------------------- 
## 1  Marginalization*Livelihoods*Dependency*Coercion  0.857  0.733  0.567    -   
##  -------------------------------------------------------------------------- 
##                                                 M1  0.857  0.733  0.567 

pimplot(data = DAT, 
        results = sol_esap, 
        outcome = "OUT1",
        jitter=TRUE,
        all_labels= TRUE)

## explains 6/10: L1, BYA, DEL, GAR, BAN, SOS
## Not explained: MCM, PAT, TEM, STE
## no contradictions in kind

########################################################################################
##
## Step 2: Simultaneous subset relations
##
###############################################

## intersect with ~Y

SSR<-intersect(rownames(TT_esa$tt)[TT_esa$tt$OUT==1],rownames(TT_ny$tt)[TT_ny$tt$OUT==1])
SSR

## none

#########################################################################
##
## Step 3: Check for contradictory assumptions
##
################################################

CSA <- intersect(rownames(sol_nyp$SA$M1), rownames(sol_esap$SA$M1))
CSA

## none

################################################################
################################################################
##
## Sufficiency ~Y
##
#########################
##
## Step 1 not necessary, as no necessary conditions
##
#########################
##
## Step 2 and 3 also not necessary, as already covered in sufficiency Y
##
## ESA solution term same as non-ESA
##
################################################################


###############################################################
###############################################################
## 
## ROBUSTNESS CHECK
##
###############################################################
###############################################################

## create initial solution

IS <- sol_esap

#########################################
###
### Step 1: Altering consistency
###
#########################################

## Altering consistency

TS1 <- minimize(data = DAT,
                outcome  = "OUT1",
                conditions = c("Livelihoods", "Marginalization", "Cultural", "Narratives", "Dependency", "Coercion", "Internal.conflicts"),
                incl.cut = 0.9,
                n.cut = 1,
                include = "?",
                details = TRUE, show.cases = TRUE)
TS1


TS2 <- minimize(data = DAT,
                outcome  = "OUT1",
                conditions = conds,
                incl.cut = 0.75,
                n.cut = 1,
                include = "?",
                details = TRUE, show.cases = TRUE)
TS2

#########################################
###
### Step 2: Altering n.cut
###
##########################################

TS3 <- minimize(data = DAT,
                outcome  = "OUT1",
                conditions = conds,
                incl.cut = 0.86,
                n.cut = 2,
                include = "?",
                details = TRUE, show.cases = TRUE)

TS3

########################################
###
### Step 3: Compare Test solutions and initial solution
###
########################################

## Create the test set in a list

TS <- list(TS1, TS2, TS3)

## Calculate robustness parameters:

RF <- rob.fit(test_sol = TS, 
              initial_sol = IS,  
              outcome = "OUT1")
RF

##                     RF_cov RF_cons RF_SC
##      Robustness_Fit  0.944   0.971 0.828

## Plotting the initial solution against the test set:

rob.xyplot(test_sol = TS, 
           initial_sol = IS, 
           outcome = "OUT1",
           fontsize = 2.5,
           jitter= TRUE)

## only one case is part of initial solution but not test solution: BYA

## Look at cases:

rob.cases(test_sol = TS, 
          initial_sol = IS,
          outcome = "OUT1")

## robust typical: 50% of all cases with the outcome
## BAN, DEL, GAR, LI1, SOS

## no robust deviants

## shaky typical: 10% of all cases with outcome
## BYA

## no shaky deviants

## no possible typicals

## no possible deviants

## extreme deviant coverage: 40% of cases with outcome

###################################################################
##
## CLUSTER DIAGNOSTICS
##
#################################################################

CS <- cluster(results = IS, 
              data = DAT, 
              outcome  = "OUT1", 
              unit_id = "Country", 
              cluster_id = "Cluster_region", 
              wicons = FALSE)
CS

## Marginalization*Livelihoods*Dependency*OUT2
## Consistency: Pooled 0.857, 1 between for all except for Lat Am (0.945)
## Coverage: 1 for CA and EU, 0.5 NA, 0.765 LatA, Oce 0.429, Afr 0.375, As 0.350



####################################################################
####################################################################
##
## ROBUSTNESS CHECK FOR ~Y
##
###########################

ISn <- sol_nyp
ISn

## Altering consistency

TS1n <- minimize(data = DAT,
                 outcome  = "~OUT1",
                 conditions = c("Livelihoods", "Marginalization", "Cultural", "Narratives", "Dependency", "Coercion", "Internal.conflicts"),
                 incl.cut = 0.9,
                 n.cut = 1,
                 include = "?",
                 details = TRUE, show.cases = TRUE)
TS1n



TS2n <- minimize(data = DAT,
                 outcome  = "~OUT1",
                 conditions = c("Livelihoods", "Marginalization", "Cultural", "Narratives", "Dependency", "Coercion", "Internal.conflicts"),
                 incl.cut = 0.8,
                 n.cut = 1,
                 include = "?",
                 details = TRUE, show.cases = TRUE)
TS2n



#########################################
###
### Step 2: Altering n.cut
###
##########################################

TS3n <- minimize(data = DAT,
                 outcome  = "~OUT1",
                 conditions = c("Livelihoods", "Marginalization", "Cultural", "Narratives", "Dependency", "Coercion", "Internal.conflicts"),                 incl.cut = 0.86,
                 n.cut = 2,
                 include = "?",
                 details = TRUE, show.cases = TRUE)
TS3n




########################################
###
### Step 3: Compare Test solutions and initial solution
###
########################################

## Create the test set in a list

TSn <- list(TS1n, TS2n, TS3n)


## Calculate robustness parameters:

RF <- rob.fit(test_sol = TSn, 
              initial_sol = ISn,  
              outcome = "~OUT1")
RF

##                    RF_cov RF_cons  RF_SC 
##     Robustness_Fit  0.665   0.951  0.617   


## Plotting the initial solution against the test set:

rob.xyplot(test_sol = TSn, 
           initial_sol = ISn, 
           outcome = "~OUT1",
           fontsize = 2.5,
           jitter= TRUE)

## IS is quite a lot larger than TS 

## Look at cases:

rob.cases(test_sol = TSn, 
          initial_sol = ISn,
          outcome = "~OUT1")

## robust typical cases: 45% of all with ~Y
## BAR, COR, JAC, KIV, LAM2, OVE, SIN, PERE, DUR-2

## robust deviant: 10%
## STE

## shaky typicals: 40% of all with ~Y
## BAB2, CAS, FOR, LEH, LEI, TOL, VID

## shaky deviant: 10%
## MCM

## possible typical: 5%
## SAI

## possible deviant: 0

## extreme deviant coverage: 10% with ~Y
## PER, DUR-1


###################################################################
##
## CLUSTER DIAGNOSTICS
##
#################################################################

CSn <- cluster(results = ISn, 
               data = DAT, 
               outcome  = "~OUT1", 
               unit_id = "Country", 
               cluster_id = "Cluster_region", 
               wicons = FALSE)
CSn


